;Tor run these examples (and any other program using vigraidl),
;please execute first:

;  CD, "/path/to/vigraidl",CURRENT=old_dir  
;  .COMPILE vigraidl
 
 
PRO examples   

PRINT, "loading blox-image"
img = loadimage(vigraidl_path() + "blox.gif")
shape = SIZE(img)

PRINT, "performance test gaussian smoothing"
PRINT, "vigra-method [in ms]:"
;(time (gsmooth img 0.3))


PRINT, "performing watershed transform on resized gradient image"
img2 = regionimagetocrackedgeimage( $
          labelimage( $
              watersheds( $
                  ggradient( $
                      resizeimage(img, 2*shape[1], 2*shape[2],  4), $
                      1.0))), $
                0.0)

PRINT, "performing fft on image"
img3 = fouriertransform(loadimage(vigraidl_path() + "rect.gif"))

PRINT, "testing rotation and reflection functions on image"
img4 = reflectimage( img, 3)
img5 = rotateimage( img, 15.0, 3)


PRINT, "testing affine transformation on image"
theta = (15 * 3.14157)/ 180.0

rotmat = [[cos(theta), -1*sin(theta), 0], $
          [sin(theta), cos(theta)   , 0], $
          [ 0        ,  0           , 1]]

t1mat = [ [1             ,  0             ,  0], $
          [0             ,  1             ,  0], $
          [-shape[1]/2.0 ,  -shape[2]/2.0 ,  1] ]  

t2mat = [ [1             ,  0            , 0], $
          [0             ,  1            , 0], $
          [shape[1]/2.0  , shape[2]/2.0  , 1] ]

img6 =  affinewarpimage( img , t2mat # rotmat # t1mat,  3)




PRINT, "performing distance transform on canny edges of image"
img7 = distancetransform(cannyedgeimage( img,  1.8,  0.1,  100.0),  0.0,  2)

PRINT, "testing difference of exponential edge detection on image"
img8 = differenceofexponentialedgeimage( img, 1.8, 0.5, 100.0)

PRINT, "testing nearly all filters"
img9  = gsmooth( img, 3.0)
img10 = laplacianofgaussian( img, 3.0)
img11 = gsharpening( img, 0.5, 3.0)
img12 = sharpening( img, 3.0)
img13 = nonlineardiffusion( img, 0.1, 2.0)

PRINT, "saving resulting images"
res = saveimage(img2, vigraidl_path() +  "blox-relabeled-watersheds-on-resized-gradient-image.png")

res = saveimage( REAL_PART(img3), vigraidl_path() +  "rect-fft-real.png")
res = saveimage( IMAGINARY(img3) , vigraidl_path() +  "rect-fft-imag.png")
res = saveimage( ABS(img3) , vigraidl_path() +  "rect-fft-magnitude.png")
res = saveimage( SQRT(ABS(img3)) , vigraidl_path() +  "rect-fft-sqrt-magnitude.png")

res = saveimage( img4 ,  vigraidl_path() +  "blox-reflected-both.png")
res = saveimage( img5 ,  vigraidl_path() +  "blox-rotated-15deg.png")
res = saveimage( img6 ,  vigraidl_path() +  "blox-aff-rotated-15deg.png")
res = saveimage( img7 ,  vigraidl_path() +  "blox-disttransform-on-canny.png")
res = saveimage( img8 ,  vigraidl_path() +  "blox-diff_of_exp.png")
res = saveimage( img9 ,  vigraidl_path() +  "blox-gsmooth-3.0.png")
res = saveimage( img10,  vigraidl_path() +  "blox-log-3.0.png")
res = saveimage( img11,  vigraidl_path() +  "blox-gsharpening-0.5-3.0.png")
res = saveimage( img12,  vigraidl_path() +  "blox-sharpening-3.0.png")
res = saveimage( img13,  vigraidl_path() +  "blox-nonlineardiffusion-0.1-2.0.png")


end