;###############################################################################
;###################          Gaussian Smoothing            ####################
FUNCTION vigra_gaussiansmoothing_c, array, array2, width, height, sigma
  RETURN, CALL_EXTERNAL(dylib_path() , 'vigra_gaussiansmoothing_c', array, array2, FIX(width), FIX(height), FLOAT(sigma), $
              VALUE=[0,0,1,1,1],/CDECL, /AUTO_GLUE)
END

FUNCTION gsmooth, array, sigma
  shape = SIZE(array)
  array2 = MAKE_ARRAY(shape[1], shape[2], /FLOAT, VALUE = 0.0)
  err = vigra_gaussiansmoothing_c(array, array2, shape[1], shape[2], sigma)
  CASE err OF
    0: RETURN, array2
    1: MESSAGE, "Error in vigraidl.filters.gsmooth: Gaussian smoothing failed!"
  ENDCASE
END


;###############################################################################
;###################      Gaussian Gradient (Magnitude)     ####################
FUNCTION vigra_gaussiangradientmagnitude_c, array, array2, width, height, sigma
  RETURN, CALL_EXTERNAL(dylib_path() , 'vigra_gaussiangradientmagnitude_c', array, array2, FIX(width), FIX(height), FLOAT(sigma), $
              VALUE=[0,0,1,1,1],/CDECL, /AUTO_GLUE)
END

FUNCTION ggradient, array, sigma
  shape = SIZE(array)
  array2 = MAKE_ARRAY(shape[1], shape[2], /FLOAT, VALUE = 0.0)
  err = vigra_gaussiangradientmagnitude_c(array, array2, shape[1], shape[2],  sigma)
  CASE err OF
    0: RETURN, array2
    1: MESSAGE, "Error in vigraidl.filters.ggradient: Gaussian gradient magnitude failed!"
  ENDCASE
END


;###############################################################################
;###################        Laplacian Of Gaussian           ####################
FUNCTION vigra_laplacianofgaussian_c, array, array2, width, height, scale
  RETURN, CALL_EXTERNAL(dylib_path() , 'vigra_laplacianofgaussian_c', array, array2, FIX(width), FIX(height), FLOAT(scale), $
              VALUE=[0,0,1,1,1],/CDECL, /AUTO_GLUE)
END

FUNCTION laplacianofgaussian, array, scale
  shape = SIZE(array)
  array2 = MAKE_ARRAY(shape[1], shape[2], /FLOAT, VALUE = 0.0)
  err = vigra_laplacianofgaussian_c(array, array2, shape[1], shape[2], scale)
  CASE err OF
    0: RETURN, array2
    1: MESSAGE, "Error in vigraidl.filters.laplacianofgaussian: Laplacian of Gaussian failed!"
  ENDCASE
END


;###############################################################################
;###################          Gaussian Sharpening           ####################
FUNCTION vigra_gaussiansharpening_c, array, array2, width, height, sharpening_factor, scale
  RETURN, CALL_EXTERNAL(dylib_path() , 'vigra_gaussiansharpening_c', array, array2, FIX(width), FIX(height), FLOAT(sharpening_factor), FLOAT(scale), $
              VALUE=[0,0,1,1,1,1],/CDECL, /AUTO_GLUE)
END

FUNCTION gsharpening, array, sharpening_factor, scale
  shape = SIZE(array)
  array2 = MAKE_ARRAY(shape[1], shape[2], /FLOAT, VALUE = 0.0)
  err = vigra_gaussiansharpening_c(array, array2, shape[1], shape[2],  sharpening_factor, scale)
  CASE err OF
    0: RETURN, array2
    1: MESSAGE, "Error in vigraidl.filters.gsharpening: Gaussian sharpening failed!"
  ENDCASE
END


;###############################################################################
;###################            Simple Sharpening           ####################
FUNCTION vigra_simplesharpening_c, array, array2, width, height, sharpening_factor
  RETURN, CALL_EXTERNAL(dylib_path() , 'vigra_simplesharpening_c', array, array2, FIX(width), FIX(height), FLOAT(sharpening_factor), $
              VALUE=[0,0,1,1,1],/CDECL, /AUTO_GLUE)
END

FUNCTION sharpening, array, sharpening_factor, scale
  shape = SIZE(array)
  array2 = MAKE_ARRAY(shape[1], shape[2], /FLOAT, VALUE = 0.0)
  err = vigra_simplesharpening_c(array, array2, shape[1], shape[2],  sharpening_factor)
  CASE err OF
    0: RETURN, array2
    1: MESSAGE, "Error in vigraidl.filters.sharpening: Simple sharpening failed!"
  ENDCASE
END

;###############################################################################
;###################          Nonlinear Diffusion           ####################
FUNCTION vigra_nonlineardiffusion_c, array, array2, width, height, edge_threshold, scale
  RETURN, CALL_EXTERNAL(dylib_path() , 'vigra_nonlineardiffusion_c', array, array2, FIX(width), FIX(height), FLOAT(edge_threshold), FLOAT(scale), $
              VALUE=[0,0,1,1,1,1],/CDECL, /AUTO_GLUE)
END

FUNCTION nonlineardiffusion, array, edge_threshold, scale
  shape = SIZE(array)
  array2 = MAKE_ARRAY(shape[1], shape[2], /FLOAT, VALUE = 0.0)
  err = vigra_nonlineardiffusion_c(array, array2, shape[1], shape[2],  edge_threshold, scale)
  CASE err OF
    0: RETURN, array2
    1: MESSAGE, "Error in vigracl.filters.nonlineardiffusion: Non linear Diffusion failed!!"
  ENDCASE
END


;###############################################################################
;###################          Distance Transform            ####################
FUNCTION vigra_distancetransform_c, array, array2, width, height, background_label, norm
  RETURN, CALL_EXTERNAL(dylib_path() , 'vigra_distancetransform_c', array, array2, FIX(width), FIX(height), FLOAT(background_label), FIX(norm), $
              VALUE=[0,0,1,1,1,1],/CDECL, /AUTO_GLUE)
END

FUNCTION distancetransform, array, background_label, norm
  shape = SIZE(array)
  array2 = MAKE_ARRAY(shape[1], shape[2], /FLOAT, VALUE = 0.0)
  err = vigra_distancetransform_c(array, array2, shape[1], shape[2], background_label, norm)
  CASE err OF
    0:  RETURN, array2 
    1:  MESSAGE, "Error in vigraidl.filters.distancetransform: Distance transformation failed!!"
    2:  MESSAGE, "Error in vigraidl.filters.distancetransform: Norm must be in {0,1,2} !!"
  ENDCASE
END